# Inizializzazione dello schermo e moduli
import pygame, random, sys, time
import classi_jungle                # modulo per le classi Scimmia e Frutto

# Inizializzazioni
pygame.init()
dim_schermo = (800,600)
finestra = pygame.display.set_mode(dim_schermo)
superficie = pygame.display.get_surface()
pygame.display.set_caption("Jungle PyGame")

# Gestione delle immagini
try:
    img_frutto = pygame.image.load("banana.png").convert()
    img_scimmia = pygame.image.load("scimmia.png").convert()
    img_sfondo = pygame.image.load("sfondo.png").convert()
except:
    print("Non è stato possibile caricare una o più immagini")
    pygame.quit()
    sys.exit(0)
    
# rende trasparente lo sfondo delle imm. prelevando il colore alla posizione (0,0)
pixel0 = (0,0)
img_frutto.set_colorkey(img_frutto.get_at(pixel0))
img_scimmia.set_colorkey(img_scimmia.get_at(pixel0))
superficie.blit(img_sfondo, pixel0)     # disegna lo sfondo

# Gestione dell’audio
try:
    pygame.mixer.init()
    pygame.mixer.music.load("suoni\sottofondo.mp3")
    caduta = pygame.mixer.Sound("suoni\splat.wav")
    presa = pygame.mixer.Sound("suoni\cattura.wav")
    if pygame.mixer.music.get_busy() == False:
        pygame.mixer.music.play()       # avvia il sottofondo
except:
    print("Non è stato possibile caricare uno o più suoni")
    pygame.quit()
    sys.exit(0)

# Casella dei punteggi
font_punteggi = pygame.font.SysFont("monospace", 12)
colore_casella_punteggi = giallo = (255,255,0)
rettangolo_punteggi = (18,18,140,58)    # rettangolo con i punteggi
colore_testo = nero = (0,0,0)
posizione_testo_1 = (20,20)
posizione_testo_2 = (20,40)
posizione_testo_3 = (20,60)

# Inizializzazione delle variabili
n_FruttiATerra = 0
n_FruttiPresi = 0
lista_frutti = []
velocita_frutti = 1             # velocità di caduta: 1 px per frame
intervallo_tra_frutti = 1       # 1 sec. tra la creazione di due frutti
velocita_scimmia = 4            # velocità orizzontale della scimmia: 4 px per frame
spostamento_scimmia = 0         # la scimmia inizia da ferma

# Gestione dei tempi
inizio = time.clock()
momento_creazione_frutto = inizio
durata = 60                     # durata del gioco in 60”
orologio = pygame.time.Clock()  # oggetto di tipo Clock per il controllo dei fps
frames_al_secondo = 60

# Creazione della scimmia
scimmia = classi_jungle.Classe_scimmia(img_scimmia, dim_schermo)

# Definizione del ciclo principale
while time.clock() < inizio + durata:

    # Cancellazione oggetti precedenti
    superficie.blit(img_sfondo, scimmia.rettangolo, scimmia.rettangolo)
    for frutto in lista_frutti:
        superficie.blit(img_sfondo, frutto.rettangolo, frutto.rettangolo)
        pygame.draw.rect(superficie, colore_casella_punteggi, rettangolo_punteggi)

    # Gestione degli eventi
    for evento in pygame.event.get():
        if evento.type == pygame.QUIT:
            pygame.mixer.stop
            pygame.quit()
            sys.exit(0)
                         
        elif evento.type == pygame.KEYDOWN:              # pressione di un tasto

            if evento.key == pygame.K_RIGHT:
                spostamento_scimmia = velocita_scimmia   # spostamento a destra
            elif evento.key == pygame.K_LEFT:
                spostamento_scimmia = - velocita_scimmia # spostamento a sinistra

        elif evento.type == pygame.KEYUP:                # rilascio di un tasto
            spostamento_scimmia = 0

    scimmia.muovi(spostamento_scimmia,dim_schermo)
    superficie.blit(img_scimmia,scimmia.rettangolo)

    # Disegno dei nuovi oggetti
    for frutto in lista_frutti:
        # se frutto e mano collidono rimuove il frutto e aggiorna i punteggi
        if frutto.rettangolo.colliderect(scimmia.rett_mano):
            lista_frutti.remove(frutto)
            n_FruttiPresi = n_FruttiPresi + 1
            presa.play() # riproduce il suono della cattura
            
        else:
        # altrimenti sposta il frutto e controlla la nuova altezza
            altezza = frutto.muovi(dim_schermo)
            if altezza == 0:
                # se arriva a terra rimuove il frutto e aggiorna i punteggi
                lista_frutti.remove(frutto)
                n_FruttiATerra = n_FruttiATerra + 1
                caduta.play() # riproduce il suono della caduta
            else:
                # altrimenti disegna il frutto nella nuova posizione
                superficie.blit(frutto.immagine,frutto.rettangolo)

    # Creazione dei nuovi frutti
    adesso = time.clock()
    if adesso - momento_creazione_frutto > intervallo_tra_frutti:
        frutto = classi_jungle.Classe_frutto(img_frutto, velocita_frutti, dim_schermo)
        lista_frutti.append(frutto)
        momento_creazione_frutto = adesso
                         
    # Aggiornamento dei punteggi
    stringa1 = "Frutti a terra:"+str(n_FruttiATerra)
    stringa2 = "Frutti presi:"+str(n_FruttiPresi)
    stringa3 = "Tempo:" + str(int(durata - (time.clock()-inizio)))

    testo1 = font_punteggi.render(stringa1, 1, colore_testo)
    testo2 = font_punteggi.render(stringa2, 1, colore_testo)
    testo3 = font_punteggi.render(stringa3, 1, colore_testo)

    superficie.blit(testo1, posizione_testo_1)
    superficie.blit(testo2, posizione_testo_2)
    superficie.blit(testo3, posizione_testo_3)

    # Visualizzazione frame e uscita
    orologio.tick(frames_al_secondo)
    pygame.display.update()
                         
pygame.mixer.stop
pygame.quit()
sys.exit()


                         
